% this program constructs vector of wighted sum of LFP of neighbors.
% This vector is stored as "LFP_spaw2" in the stata dataset "PANEL_ECMA"
%  
% It uses the function xy2cont to construct weight matrix. 
% function [wswdel,wwsdel,wmatdel]=xy2cont(xcoord,ycoord)
% PURPOSE: uses x,y coordinates to produce spatial contiguity weight matrices
%          with delaunay routine from MATLAB version 5.2
% ------------------------------------------------------
% USAGE: [w1 w2 w3] = xy2cont(xcoord,ycoord)
% where:     xcoord = x-direction coordinate
%            ycoord = y-direction coordinate
% ------------------------------------------------------
% RETURNS: w1 = W*W*S, a row-stochastic spatial weight matrix
%          w2 = W*S*W, a symmetric spatial weight matrix (max(eig)=1)
%          w3 = diagonal matrix with i,i equal to 1/sqrt(sum of ith row)
% ------------------------------------------------------
% References: Kelley Pace, Spatial Statistics Toolbox 1.0
% ------------------------------------------------------

% We use w2 as our matrix of spatial weights and we construct LFP_spaw2
 


clear

load fips3074latlon.txt
fipslist=fips3074latlon(:,1);
xcoord=fips3074latlon(:,2);
ycoord=fips3074latlon(:,3);
lfp40=fips3074latlon(:,4);
lfp50=fips3074latlon(:,5);
lfp60=fips3074latlon(:,6);
lfp70=fips3074latlon(:,7);
lfp80=fips3074latlon(:,8);
lfp90=fips3074latlon(:,9);
lfp00=fips3074latlon(:,10);

[w1 w2 w3]=xy2cont(xcoord,ycoord);


LFP_spaw240=w2*lfp40;
LFP_spaw250=w2*lfp50;
LFP_spaw260=w2*lfp60;
LFP_spaw270=w2*lfp70;
LFP_spaw280=w2*lfp80;
LFP_spaw290=w2*lfp90;
LFP_spaw200=w2*lfp00;

LFP_spaw2=[LFP_spaw240;LFP_spaw250;LFP_spaw260;LFP_spaw270;LFP_spaw280;LFP_spaw290;LFP_spaw200];

% Check spatial weight matrix using the function UScounty_border_contig which only needs
% fips as input. It applies the contiguity matrix already constructed using
% Arcview Spacestat and stored in UScbcont.txt. It gives a 1 to the correspondent entry and stores in sparse form.

cbcontig=UScounty_border_contig(fipslist);

% Comparing positive entries for first county, there is one discrepancy
% using triangles for a county which is very close but not contiguous.

