% This program calculates Moran I and standard deviation on residuals.
% It runs year by year regressions
% It loads year by year variables from dataset PANEL_ECMA.dta


clear

filenames=['ECMA40.txt';
          'ECMA50.txt';
          'ECMA60.txt';
          'ECMA70.txt';
          'ECMA80.txt';
          'ECMA90.txt';
          'ECMA00.txt'];

          

year=1940
for j=1:7;  % loop over years

    
    ECMA=load(filenames(j,:));


fipslist=ECMA(:,1);
lfp=ECMA(:,2);
dens=ECMA(:,3);
pc_urb=ECMA(:,4);
pc_farm=ECMA(:,5);
pc_w=ECMA(:,6);
pc_oth=ECMA(:,7);
pc_wholest=ECMA(:,8);
pc_servest=ECMA(:,9);
pc_retail=ECMA(:,10);
avg_edu=ECMA(:,11);
xcoord=ECMA(:,12);
ycoord=ECMA(:,13);

%% Run the benchmark regression

[n,m]=size(ECMA);
cons=ones(n,1);
X=[cons ECMA(:,3:11)];
results = ols(lfp,X);

%% Construct weights matrix 

%cbcontig=UScounty_border_contig(fipslist);
[w1 w2 w3]=xy2cont(xcoord,ycoord);

%% Construct residuals and calculate standard deviation and Moran I

error=results.resid;
stde=std(error);
stdv(j,2)=stde;
stdv(j,1)=year;

output=moran(lfp,X,w2);
moranv(j,2) = output.morani;
moranv(j,1) = year;

year=year+10

end

plot(moranv(:,1),moranv(:,2))
figure
plot(stdv(:,1),stdv(:,2))
