clear history; clear regionhistory; clear;
global LFP_init wage_init pop_weight
global mu_a sig_a mu_ome sig_ome j sig_theta_all
randn('state',0);  % Reset the random number generators
rand('state',0);  % Reset the random number generators


grid;
load distance;
LFP_init = cell_lfp/5.5/100;  % divide by 2.75 to get married w/kids in 1940 and then by 2 to get 1930
vregavg_old=vec(LFP_init);



pop_w = cell_pop;
pop_weight = pop_w./sum(sum(pop_w));
sign_mat = [ 4     4     5     4     3     3     3     4     4     4
     5     3     3     3     3     3     3     3     4     4
     3     4     3     3     3     4     3     3     3     3
     3     4     4     3     4     4     3     3     3     3
     4     4     4     4     4     4     4     4     4     4
     4     4     4     4     4     4     4     4     4     4
     4     4     5     5     5     5     5     5     4     4
     4     4     4     4     5     5     5     5     5     4
     4     5     5     5     5     5     5     4     5     4
     5     5     5     5     5     4     4     4     3     4];
     
 
dens_mat=sign_mat;     % This is the matrix of number of signal drawn in any region (it will depend on density)


%% %%%%%%%%%%%%%%%%%%%%%%%%   Values of parameters
p=rand;
msz = 5;                        % this is the maximum number of signals
nc = 55;                        % sq root of the number of counties (55 makes for 3025 counties. 3074 in our sample) 
rpop=nc;                        % square root of individuals per region 
L=0.3;                          % 2.2 value of leisure
range = (sqrt(0.0026)/2);       % you observe signals from the closest (2*range)^2 fract of pop. At <= 40 miles 0.026% of population.
cdis=2;                         % distance among counties in the model which is equivalent to 40 miles in data. Each county has about other 8 counties which are closer than 40 miles

% ability parameters
abilities_gap=0.45;                        %0.675 initial difference in the data % married women with child less than 5 (W,F,GQ,25-54,FTYR, + earnings)/ their respective husbands 
sig_a=0.57;                                %0.53 initial sd log wage in the data
mu_a=log(abilities_gap)-(sig_a^2)/2;       % mean log ability
mu_a_all = mu_a;

% endowment parameters
sig_ome=0.75;                   % sd of log endowment (from data)
mu_ome=-(sig_ome^2)/2;          % mean log endowment (it is chosen such that mean endowment is normalized to 1)
mu_end=exp(mu_ome+(sig_ome^2)/2);

% the effect of maternal employment on child's outcome: initial beliefs and truth

mu_theta=0.04;                 % mean priors over teta
sig_theta=1.38*.55;            % sd prior over teta
tru_theta=0.04;                % true mean of log teta  

% preferences params
gamac=3;                     % curvature on consumption
gamak=3;                     % curvature on expected income of the kid




%% Initial conditions: impose labor choices and ability by region
regions =rows(LFP_init);        % sqr. root of number of regions (10 makes for 100 regions - true # is 3086)
np = rpop*regions;

% map initial regional LFP into an np-by-np matrix of inidiv initial conditions (past labor supply)

pp=kron(LFP_init,ones(rpop));
qq=rand(rpop*regions);
n=qq<pp;

%Generate matrices (np-by-np) of common priors
mu_theta_all=mu_theta*ones(np,np);                     
sig_theta_all = sig_theta*ones(np,np);
mu_end_all=mu_end*ones(np,np);  % endowment mean
prec_theta_all=sig_theta_all.^(-2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  PLEASE DELETE ME  %%%%%%
%load merda
%mu_theta_all = muxxx;
%sig_theta_all = mean(mean(thetaxxx)); %thetaxxx;
%n = nxxx;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Set up matrices - define objects

nt=0;
position=zeros(np,np,msz,2);  % This is a 4D array!
depvar_sample=zeros(np,np,msz);
n_sample=zeros(np,np,msz);
n_old = zeros(np,np);
history(1,1)=0.03;
history(1,9)= mu_theta;
history(1,10)= 0;
history(1,11)= sig_theta;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Begin Loop
while nt<8; % should be 8 to match data  
    
    nt=nt+1;
    disp('Computing period: ')
    disp(nt)
    
    % Draw endowments and log wages
    endowment=exp(randn(np,np)*sig_ome+mu_ome);             % endowment
    ability=exp(randn(np,np)*sig_a+mu_a_all);               % ability
    lwage=log(ability) - (n*tru_theta);
    wage = exp(lwage);
    depvar=lwage-mu_a_all;
   
    % DRAWING SIGNALS %%%
    for i=1:1:np
      for j = 1:1:np, 
       
     
        sz=dens_mat(1+floor(i*.9999/rpop),1+floor(j*.9999/rpop));   % assign the number of signal the woman receive (it depends on the region where she lives)
        rndi = rand(sz,1);     rndj = rand(sz,1); % draw J random numbers between 0 and 1
        hiloi = (rand(sz,1)>0.5); % will your draw be to the east or west of you? vector of zero/ones
        hiloj = (rand(sz,1)>0.5); % will your draw be to the north or south of you?
        ic = (i)/np;  % this is your horiz position. Signals are concentrated around ic.
        jc = (j)/np;  % this is your vertical position.
        mini = max(ic-range,0)-ic; minj = max(jc-range,0)-jc; % if ic-range>0, then mini is -range. otherwise mini is -ic
        maxi = min(ic+range,1)-ic; maxj = min(jc+range,1)-jc; % if ic+range<1, then maxi is +range. otherwise maxi is 1-ic
        % this draws uniformly from a set above and then below (ic,jc)
        % then it selects between high or low draw w/prob 0.5
        dhii = i+ ceil(rndi*maxi*np);
        dloi = i+ ceil(rndi*mini*np);
        dhij = j+ ceil(rndj*maxj*np);
        dloj = j+ ceil(rndj*minj*np);

        drawsi= hiloi.*dhii + (1-hiloi).*dloi;
        drawsj=hiloj.*dhij + (1-hiloj).*dloj;
        position(i,j,1:sz,1)=drawsi;
        position(i,j,1:sz,2)=drawsj;

        for k = 1:sz-1,
            % these are the wage realizations you see
           depvar_sample(i,j,k)=depvar(position(i,j,k,1),position(i,j,k,2));
            % these are the maternal employment decisions you see.
           n_sample(i,j,k)=n(position(i,j,k,1),position(i,j,k,2));
        end        
      end 
    end

    % Add your own observation to the matrix of sample observations
    depvar_sample(:,:,sz)=depvar;
    n_sample(:,:,sz)=n;
    n_bar=sum(n_sample,3);  % this is np x np.

    
    %%%%%%%%%
        if mean(std(mu_theta_all))>0.01,
        %%%%%%%%%%  EXTRA INFO FROM MOTHER'S LABOR DECISION %%%%
        % distribution of beliefs last period of women who worked.
        %%%  Regression approach  %%%%
        regl=ols(vec(cc-mean(mean(cc))), vec(mu_theta_all-mean(mean(mu_theta_all))));
        signoise = inv(regl.rsqr);
        sigstdw = signoise*mean(vec(sig_theta_all));
        % add signal with same precision
        exinfo = mu_theta;
        expre = sigstdw.^(-2);
        exmean = mu_theta + randn(size(theta_hat))*sigstdw;
    else
        expre=0;
        exmean=0;
    end

    %Update beliefs after observing draws. Note some women observe no woman
    %working and nbar for them is zero.
      theta_hat =-sum(depvar_sample.*n_sample,3)./(n_bar+.001*(n_bar==0));  %last bit makes sure this isn't inf     
      prec_theta_hat=n_bar/(sig_a^2);

      prec_theta_new=prec_theta_all+prec_theta_hat +expre;
      post_mu_all= (prec_theta_all.*mu_theta_all +prec_theta_hat.*theta_hat + expre.*exmean)./prec_theta_new;
      sig_theta_all = prec_theta_all.^(-1/2);
      prec_theta_all = prec_theta_new;
      post_var_all=(prec_theta_all).^(-1);
      post_sig_all=(post_var_all).^(1/2);
      %%%%%%%%%%%%%%%%%

    % Calculate expected value from working and not working
    utility1=(1/(1-gamac))*(wage+ endowment).^(1-gamac)+(1/(1-gamac))*exp((mu_a_all-post_mu_all).*(1-gamac)+1/2*(sig_a^2+post_var_all).*(1-gamac)^2);
    utility0=(1/(1-gamac))* endowment.^(1-gamac)+(1/(1-gamac))*exp(mu_a_all.*(1-gamac)+1/2*sig_a^2.*(1-gamac)^2)+L;
    cc=(utility1>=utility0);
  

   % select the wages, endowments and log wages of working women
    wagew=wage(cc>0);
    endwork=endowment(cc>0);
    lwagew=log(wagew);
    
    % compute stats
    mean_ww=mean(wagew);
    std_lww=std(lwagew);
    mean_endw=mean(endwork); 
    wgap=mean_ww/mean_endw;   
    
   
    
%% COMPUTE COUNTY-LEVEL STATISTICS
    % CREATE A 55 x 55 MATRIX OF county LFPs
    % this is a counties-by-np matrix that sums lfp by county
    
    ctymat = kron(eye(nc),ones(1,np/nc));
    ctylfpH = (ctymat*cc*nc/np);
    ctylfpR = ctylfpH*ctymat'*nc/np;
   
    
    %% put counties in vector form 
     
    vlfp=vec(ctylfpR);
    lfp_unweight= sum(sum(ctylfpR))/length(vlfp);
    
    
    % Dispersion Measures
    
    cty_std= std(vlfp);
    
    if nt>1
        vlfp_growth=vlfp - vlfp_old;
        cty_grstd=std(vlfp_growth);
        history(nt,6)=cty_grstd;
    end
    vlfp_old=vlfp;
    
    %% COMPUTE region-LEVEL STATISTICS
    % CREATE A 10 x 10 MATRIX OF county LFP dispersion
    
    regmat = kron(eye(10),ones(1,np/10));
    reglfpH = (regmat*cc*10/np);
    regavg = reglfpH*regmat'*10/np;  %(10 x 10)
    vregavg=vec(regavg);
    % how much an individual differs from regional average, squared
    deviation_reg = (cc - kron(regavg,ones(55))).^2;  %550 x 550
    % sum the square deviation => stdev
    regsumsq = regmat*deviation_reg*regmat'*(10/np)^2;   %10 x 10
    % take an average
    reg_std = regsumsq;
    
    % adjust individual std to be a std across counties
    reg_std_adj = reg_std/(100)^1/2;
    
     if nt>1
        vreg_growth=vregavg- vregavg_old;
    end
    vregavg_old=vregavg;

     
    % compute model's Moran's I
    %uni=vlfp*0+1;       %create a vector of constants
    %rmoran = moran(vlfp,uni,dmat<cdis); 
    %cty_moran= rmoran.morani;
    
    %% compute participation of women w/o kids
    utility1nk =(1/(1-gamac))*(wage+ endowment).^(1-gamac)+(1/(1-gamac))*exp((mu_a_all- 0).*(1-gamac)+1/2*(sig_a^2+0).*(1-gamac)^2);
    utility0nk =(1/(1-gamac))* endowment.^(1-gamac)+(1/(1-gamac))*exp(mu_a_all.*(1-gamac)+1/2*sig_a^2.*(1-gamac)^2)+L;
    ccnk =(utility1nk >= utility0nk);
    ccnkvec=vec(ccnk);
    lfp_nok=mean(ccnkvec);
    
    %% SURVEY RESPONSES
    obswage=exp(depvar_sample+mu_a);
    avobswage=mean(obswage,3);
    avutility1=(1/(1-gamac))*(avobswage+mu_end_all).^(1-gamac)+(1/(1-gamac))*exp((mu_a_all- mu_theta_all).*(1-gamac)+1/2*(sig_a^2+sig_theta_all.^2).*(1-gamac)^2);
    avutility0=(1/(1-gamac))*mu_end_all.^(1-gamac)+(1/(1-gamac))*exp(mu_a_all.*(1-gamac)+1/2*sig_a^2.*(1-gamac)^2);
    cc_survey=(avutility0>=avutility1);
    survey_count=sum(sum(cc_survey));
    survey=1-survey_count/np^2;
    

    
     %% UPDATE BELIEFS AND LABOR CHOICES
    mu_theta_all=post_mu_all;
    sig_theta_all=post_sig_all; 
    n=cc;                                           % labor force participation of mothers
  
   % history is a matrix: nperiods x 8
    % 1 = LFP, 2 = Mean(E(theta)) 3= Std(E(theta)) 4 = Mean (Std(theta))
    % 5 = Mean earnings of working women  6 = mean endowment of working women    

    history(nt+1,1)=sum(vec(cc))/(np^2);
    history(nt,2)= mean_ww;
    history(nt,3)=mean_endw;
    history(nt,4)=cty_std;
    %history(nt,5)=cty_moran;
    history(nt,7)=lfp_nok;
    history(nt,8)=survey;
    history(nt+1,9)=mean(vec(mu_theta_all));
    history(nt+1,10)=std(vec(mu_theta_all));
    history(nt+1,11)=mean(vec(sig_theta_all));
    history(nt,12)=wgap;
   
  
end


tline1=[1930 1940 1950 1960 1970 1980 1990 2000 2005];
tline2=[ 1940 1950 1960 1970 1980 1990 2000 2005];
tline3=[1930 1940 1950 1960 1970 1980 1990 2000];
tline4=[ 1940 1950 1960 1970 1980 1990 2000];
lfpdata=[0.03 0.0672 0.0984 0.1688 0.2411 0.4146 0.593 0.5964 0.5911]*100;
wagedata=[0.675 0.6111 0.56 0.53 0.589 0.678 0.616 0.661]*100;
endata=[82.9 83.7 83.7 86.4 89.7 90.5 89.3 89.1];
wgapdata=wagedata./endata;
srpx=[1936 1945 1977 1985 1986 1988 1989 1990 1991 1993 1994 1996 1998 2000 2002 2004];
srpy=[8.22 8.22 32.71 46.03 48.82 51.81 51.95 50.56 52.21 56.87 57.54 53.75 57.66 52.55 54.34 57.97];
stdevlfp_data=[3.94 4.48 4.91 5.09 5.13 5.05 3.95];
stdevlfp_data_adj=[0.73 1.46 2.00 2.85 3.53 5.02 5.91 5.11];
stdgrdata=[3.80 4.11 4.16 3.75 3.46 3.35];
moranI_data=[0.432 0.447 0.429 0.507 0.518 0.515 0.383];% last number is either .458 or .383



figure(1)
subplot(1,2,1)

plot(tline1,history(:,1)*100, tline1, lfpdata,'-x', 'LineWidth',2);
legend('Model','Data','Location','NorthWest','FontSize',14);
title('Labor Force Participation','FontSize',14)
axis([1930 2005 0 80]);


 subplot (1,2,2)
plot(tline2,history(1:8,4)*100,tline4,stdevlfp_data_adj(:,2:8),'-x', 'LineWidth',2);
 title('Cross-County LFP Dispersion','FontSize',14)
axis([1930 2005 0 8]);
 